Description Usage Arguments Details Value See Also
View source: R/class_methods_helpers.R
Tests if the x object is of class type "GSVD"
1 | is_GSVD(x)
|
x |
object to test |
The three primary functions in the GSVD package produce an inherited (hierarchical) class structure where all of them are of type "GSVD". Those functions are geigen, gsvd, and gplssvd.
boolean. TRUE if the object is of class GSVD, FALSE otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.