Description Usage Arguments Details Value See Also
View source: R/class_methods_helpers.R
Tests if the x object is of class type "geigen"
1 |
x |
object to test |
Only geigen produces this class type.
boolean. TRUE if the object is of class geigen, FALSE otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.